@@ -11,9 +11,9 @@ use File::chdir;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-02'; # DATE
+our $DATE = '2023-11-14'; # DATE
 our $DIST = 'App-FileSortUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our %SPEC;
 
@@ -22,10 +22,14 @@ my @file_types = qw(file dir);
 my @file_fields = qw(name size mtime ctime);
 
 our %argspecs_common = (
-    dir => {
+    dirs => {
+        'x.name.is_plural' => 1,
+        'x.name.singular' => 'dir',
         summary => 'Directory to sort files of, defaults to current directory',
-        schema => 'dirname::default_curdir',
+        schema => ['array*', of=>'dirname*', min_len=>1],
+        default => ['.'],
         pos => 0,
+        slurpy => 1,
         tags => ['category:input'],
     },
 
@@ -149,7 +153,7 @@ our %argspec_ignore_case = (
 
 $SPEC{sort_files} = {
     v => 1.1,
-    summary => 'Sort files in a directory and display the result in a flexible way',
+    summary => 'Sort files in one or more directories and display the result in a flexible way',
     description => <<'MARKDOWN',
 
 
@@ -169,63 +173,68 @@ sub sort_files {
     my %args = @_;
     my $all = $args{all} // 0;
 
-    my $dir = $args{dir} // '.';
-    opendir my $dh, $dir or return [500, "Can't opendir '$dir': $!"];
-    my @files;
-  GET_FILES: {
-        local $CWD = $dir;
-      FILE:
-        while (defined(my $e = readdir $dh)) {
-            next if $e eq '.' || $e eq '..';
-            if (defined $args{include_filename_pattern}) {
-                unless ($e =~ $args{include_filename_pattern}) {
-                    log_trace "File $e excluded (not match $args{include_filename_pattern})";
-                    next FILE;
-                }
-            }
-            if (defined $args{exclude_filename_pattern}) {
-                if ($e =~ $args{exclude_filename_pattern}) {
-                    log_trace "File $e excluded (matches $args{exclude_filename_pattern})";
-                    next FILE;
-                }
-            }
-            if (!$all) {
-                if ($e =~ /\A\./) {
-                    log_trace "File $e excluded (dotfile hidden)";
-                    next FILE;
-                }
-            }
-            my $rec = {name=>$e};
-            my @st = lstat $e or do {
-                warn "Can't stat '$e' in '$dir': $!, skipped";
-                next;
-            };
-            $rec->{size} = $st[7];
-            $rec->{mtime} = $st[9];
-            $rec->{ctime} = $st[10];
-            $rec->{mode} = $st[2];
-          FILTER: {
-                if (defined $args{type}) {
-                    if ($args{type} eq 'file') {
-                        unless ($rec->{mode} & S_IFREG) {
-                            log_trace "File '$e' in '$dir': not a regular file, skipped";
-                            next FILE;
-                        }
-                    } elsif ($args{type} eq 'dir') {
-                        unless ($rec->{mode} & S_IFDIR) {
-                            log_trace "File '$e' in '$dir': not a directory, skipped";
-                            next FILE;
-                        }
-                    } else {
-                        return [400, "Invalid value of type '$args{type}'"];
+    my $dirs = $args{dirs} // ['.'];
+
+    my @recs;
+  DIR:
+    for my $dir (@$dirs) {
+        opendir my $dh, $dir or return [500, "Can't opendir '$dir': $!"];
+
+      GET_FILES: {
+            local $CWD = $dir;
+          FILE:
+            while (defined(my $e = readdir $dh)) {
+                next if $e eq '.' || $e eq '..';
+                if (defined $args{include_filename_pattern}) {
+                    unless ($e =~ $args{include_filename_pattern}) {
+                        log_trace "File $e excluded (not match $args{include_filename_pattern})";
+                        next FILE;
                     }
                 }
-            }
+                if (defined $args{exclude_filename_pattern}) {
+                    if ($e =~ $args{exclude_filename_pattern}) {
+                        log_trace "File $e excluded (matches $args{exclude_filename_pattern})";
+                        next FILE;
+                    }
+                }
+                if (!$all) {
+                    if ($e =~ /\A\./) {
+                        log_trace "File $e excluded (dotfile hidden)";
+                        next FILE;
+                    }
+                }
+                my $rec = {name=>$e, dir=>$dir};
+                my @st = lstat $e or do {
+                    warn "Can't stat '$e' in '$dir': $!, skipped";
+                    next;
+                };
+                $rec->{size} = $st[7];
+                $rec->{mtime} = $st[9];
+                $rec->{ctime} = $st[10];
+                $rec->{mode} = $st[2];
+              FILTER: {
+                    if (defined $args{type}) {
+                        if ($args{type} eq 'file') {
+                            unless ($rec->{mode} & S_IFREG) {
+                                log_trace "File '$e' in '$dir': not a regular file, skipped";
+                                next FILE;
+                            }
+                        } elsif ($args{type} eq 'dir') {
+                            unless ($rec->{mode} & S_IFDIR) {
+                                log_trace "File '$e' in '$dir': not a directory, skipped";
+                                next FILE;
+                            }
+                        } else {
+                            return [400, "Invalid value of type '$args{type}'"];
+                        }
+                    }
+                } # FILTER
 
-            push @files, $rec;
-        }
-        closedir $dh;
-    } # GET_FILES
+            push @recs, $rec;
+            }
+            closedir $dh;
+        } # GET_FILES
+    } # DIR
 
     my ($code_key, $code_cmp);
   SET_CODE_CMP: {
@@ -267,7 +276,7 @@ sub sort_files {
         return [400, "Please specify one of by_field/by_sortsub/by_code"];
     } # SET_CODE_CMP
 
-    my (@ranks, @sorted_files);
+    my (@ranks, @sorted_recs);
   SORT: {
         require List::Rank;
 
@@ -285,18 +294,18 @@ sub sort_files {
                 }
                 $args{reverse} ? $code_cmp->($key2, $key1) : $code_cmp->($key1, $key2);
             },
-            @files
+            @recs
         );
         while (my ($e1, $e2) = splice @res, 0, 2) {
-            push @sorted_files, $e1;
+            push @sorted_recs, $e1;
             push @ranks, $e2;
         }
     } # SORT
 
   NUM_RESULTS: {
         last unless defined $args{num_results} && $args{num_results} > 0;
-        last unless $args{num_results} < @sorted_files;
-        splice @sorted_files, $args{num_results};
+        last unless $args{num_results} < @sorted_recs;
+        splice @sorted_recs, $args{num_results};
     }
 
   NUM_RANKS: {
@@ -305,23 +314,22 @@ sub sort_files {
         my $i = -1;
         while (1) {
             $i++;
-            last if $i >= @sorted_files;
+            last if $i >= @sorted_recs;
             my $rank = $ranks[$i];
             $rank =~ s/=\z//;
             last if $rank > $args{num_ranks};
-            push @res, $sorted_files[$i];
+            push @res, $sorted_recs[$i];
         }
-        @sorted_files = @res;
+        @sorted_recs = @res;
     }
 
     if ($args{detail}) {
-        for (@sorted_files) { $_->{dir} = $dir }
     } else {
-        @sorted_files = map { ($dir eq '.' ? '' : $dir eq '/' ? '/' : "$dir/") . $_->{name} } @sorted_files;
+        @sorted_recs = map { ($_->{dir} eq '.' ? '' : $_->{dir} eq '/' ? '/' : "$_->{dir}/") . $_->{name} } @sorted_recs;
     }
-    log_info "Sorted files: %s", \@sorted_files;
+    log_info "Sorted files: %s", \@sorted_recs;
 
-    [200, "OK", \@sorted_files];
+    [200, "OK", \@sorted_recs];
 }
 
 # foremost
@@ -337,6 +345,7 @@ gen_modified_sub(
     description => <<'MARKDOWN',
 
 Notes:
+
 - by default dotfiles are not included, use `--all` (`-a`) to include them
 
 Some examples:
@@ -373,6 +382,7 @@ gen_modified_sub(
     description => <<'MARKDOWN',
 
 Notes:
+
 - by default dotfiles are not included, use `--all` (`-a`) to include them
 
 Some examples:
@@ -403,7 +413,7 @@ gen_modified_sub(
     output_name => 'largest',
     base_name => 'sort_files',
     remove_args => [keys %argspecs_sort],
-    summary => 'Return the largest file(s) in a directory',
+    summary => 'Return the largest file(s) in one or more directories',
     description => <<'MARKDOWN',
 
 Some examples:
@@ -437,7 +447,7 @@ gen_modified_sub(
     output_name => 'smallest',
     base_name => 'sort_files',
     remove_args => [keys %argspecs_sort],
-    summary => 'Return the smallest file(s) in a directory',
+    summary => 'Return the smallest file(s) in one or more directories',
     description => <<'MARKDOWN',
 
 Some examples:
@@ -470,10 +480,11 @@ gen_modified_sub(
     output_name => 'newest',
     base_name => 'sort_files',
     remove_args => [keys %argspecs_sort],
-    summary => 'Return the newest file(s) in a directory',
+    summary => 'Return the newest file(s) in one or more directories',
     description => <<'MARKDOWN',
 
 Notes:
+
 - by default dotfiles are not included, use `--all` (`-a`) to include them
 
 Suppose a new file is downloaded in `~/Downloads`, but you are not sure of its
@@ -523,10 +534,11 @@ gen_modified_sub(
     output_name => 'oldest',
     base_name => 'sort_files',
     remove_args => [keys %argspecs_sort],
-    summary => 'Return the oldest file(s) in a directory',
+    summary => 'Return the oldest file(s) in one or more directories',
     description => <<'MARKDOWN',
 
 Notes:
+
 - by default dotfiles are not included, use `--all` (`-a`) to include them
 
 File is deemed as oldest by its mtime.
@@ -561,10 +573,11 @@ gen_modified_sub(
     output_name => 'longest_name',
     base_name => 'sort_files',
     remove_args => [keys %argspecs_sort],
-    summary => 'Return file(s) with the longest name in a directory',
+    summary => 'Return file(s) with the longest name in one or more directories',
     description => <<'MARKDOWN',
 
 Notes:
+
 - by default dotfiles are not included, use `--all` (`-a`) to include them
 
 Some examples:
@@ -597,10 +610,11 @@ gen_modified_sub(
     output_name => 'shortest_name',
     base_name => 'sort_files',
     remove_args => [keys %argspecs_sort],
-    summary => 'Return file(s) with the shortest name in a directory',
+    summary => 'Return file(s) with the shortest name in one or more directories',
     description => <<'MARKDOWN',
 
 Notes:
+
 - by default dotfiles are not included, use `--all` (`-a`) to include them
 
 Some examples:
@@ -628,7 +642,7 @@ MARKDOWN
 );
 
 1;
-# ABSTRACT: Utilities related to sorting files in a directory
+# ABSTRACT: Utilities related to sorting files in one or more directories
 
 __END__
 
@@ -638,11 +652,11 @@ __END__
 
 =head1 NAME
 
-App::FileSortUtils - Utilities related to sorting files in a directory
+App::FileSortUtils - Utilities related to sorting files in one or more directories
 
 =head1 VERSION
 
-This document describes version 0.006 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-11-02.
+This document describes version 0.007 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-11-14.
 
 =head1 DESCRIPTION
 
@@ -682,7 +696,12 @@ Usage:
 Return file(s) which are alphabetically the first.
 
 Notes:
-- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=over
+
+=item * by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=back
 
 Some examples:
 
@@ -703,7 +722,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -763,7 +782,12 @@ Usage:
 Return file(s) which are alphabetically the last.
 
 Notes:
-- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=over
+
+=item * by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=back
 
 Some examples:
 
@@ -784,7 +808,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -841,7 +865,7 @@ Usage:
 
  largest(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Return the largest file(s) in a directory.
+Return the largest file(s) in one or more directories.
 
 Some examples:
 
@@ -866,7 +890,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -919,10 +943,15 @@ Usage:
 
  longest_name(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Return file(s) with the longest name in a directory.
+Return file(s) with the longest name in one or more directories.
 
 Notes:
-- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=over
+
+=item * by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=back
 
 Some examples:
 
@@ -947,7 +976,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -1000,10 +1029,15 @@ Usage:
 
  newest(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Return the newest file(s) in a directory.
+Return the newest file(s) in one or more directories.
 
 Notes:
-- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=over
+
+=item * by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=back
 
 Suppose a new file is downloaded in C<~/Downloads>, but you are not sure of its
 name. You just want to move that file, which you are pretty sure is the newest
@@ -1044,7 +1078,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -1097,10 +1131,15 @@ Usage:
 
  oldest(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Return the oldest file(s) in a directory.
+Return the oldest file(s) in one or more directories.
 
 Notes:
-- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=over
+
+=item * by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=back
 
 File is deemed as oldest by its mtime.
 
@@ -1127,7 +1166,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -1180,10 +1219,15 @@ Usage:
 
  shortest_name(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Return file(s) with the shortest name in a directory.
+Return file(s) with the shortest name in one or more directories.
 
 Notes:
-- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=over
+
+=item * by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
+=back
 
 Some examples:
 
@@ -1208,7 +1252,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -1261,7 +1305,7 @@ Usage:
 
  smallest(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Return the smallest file(s) in a directory.
+Return the smallest file(s) in one or more directories.
 
 Some examples:
 
@@ -1286,7 +1330,7 @@ Do not ignore entries starting with .
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -1339,7 +1383,7 @@ Usage:
 
  sort_files(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Sort files in a directory and display the result in a flexible way.
+Sort files in one or more directories and display the result in a flexible way.
 
 This function is not exported.
 
@@ -1367,7 +1411,7 @@ Sort::Sub routine name to sort.
 
 (No description)
 
-=item * B<dir> => I<dirname::default_curdir>
+=item * B<dirs> => I<array[dirname]> (default: ["."])
 
 Directory to sort files of, defaults to current directory.
 
@@ -1451,6 +1495,8 @@ Source repository is at L<https://github.com/perlancar/perl-App-FileSortUtils>.
 
 =head1 SEE ALSO
 
+L<App::DownloadsDirUtils>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
